@@ -1,5 +1,6 @@
 //! Functions which operate on file descriptors.
 
+use crate::fs::Timestamps;
 use crate::io::SeekFrom;
 #[cfg(not(target_os = "wasi"))]
 use crate::process::{Gid, Uid};
@@ -7,18 +8,23 @@ use crate::{imp, io};
 use imp::fd::{AsFd, BorrowedFd};
 #[cfg(not(any(
     target_os = "dragonfly",
+    target_os = "illumos",
     target_os = "netbsd",
     target_os = "openbsd",
     target_os = "redox"
 )))]
 use imp::fs::FallocateFlags;
 use imp::fs::Stat;
-#[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "wasi")))]
+#[cfg(not(any(
+    target_os = "illumos",
+    target_os = "netbsd",
+    target_os = "redox",
+    target_os = "wasi"
+)))]
 // not implemented in libc for netbsd yet
 use imp::fs::StatFs;
 #[cfg(not(target_os = "wasi"))]
 use imp::fs::{FlockOperation, Mode};
-use imp::time::Timespec;
 
 /// `lseek(fd, offset, whence)`—Repositions a file descriptor within a file.
 ///
@@ -31,7 +37,7 @@ use imp::time::Timespec;
 #[inline]
 pub fn seek<Fd: AsFd>(fd: &Fd, pos: SeekFrom) -> io::Result<u64> {
     let fd = fd.as_fd();
-    imp::syscalls::seek(fd, pos)
+    imp::fs::syscalls::seek(fd, pos)
 }
 
 /// `lseek(fd, 0, SEEK_CUR)`—Returns the current position within a file.
@@ -49,7 +55,7 @@ pub fn seek<Fd: AsFd>(fd: &Fd, pos: SeekFrom) -> io::Result<u64> {
 #[inline]
 pub fn tell<Fd: AsFd>(fd: &Fd) -> io::Result<u64> {
     let fd = fd.as_fd();
-    imp::syscalls::tell(fd)
+    imp::fs::syscalls::tell(fd)
 }
 
 /// `fchmod(fd)`—Sets open file or directory permissions.
@@ -67,7 +73,7 @@ pub fn tell<Fd: AsFd>(fd: &Fd) -> io::Result<u64> {
 #[inline]
 pub fn fchmod<Fd: AsFd>(fd: &Fd, mode: Mode) -> io::Result<()> {
     let fd = fd.as_fd();
-    imp::syscalls::fchmod(fd, mode)
+    imp::fs::syscalls::fchmod(fd, mode)
 }
 
 /// `fchown(fd)`—Sets open file or directory ownership.
@@ -82,21 +88,26 @@ pub fn fchmod<Fd: AsFd>(fd: &Fd, mode: Mode) -> io::Result<()> {
 #[inline]
 pub fn fchown<Fd: AsFd>(fd: &Fd, owner: Uid, group: Gid) -> io::Result<()> {
     let fd = fd.as_fd();
-    imp::syscalls::fchown(fd, owner, group)
+    imp::fs::syscalls::fchown(fd, owner, group)
 }
 
 /// `fstat(fd)`—Queries metadata for an open file or directory.
 ///
+/// [`Mode::from_raw_mode`] and [`FileType::from_raw_mode`] may be used to
+/// interpret the `st_mode` field.
+///
 /// # References
 ///  - [POSIX]
 ///  - [Linux]
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/fstat.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/fstat.2.html
+/// [`Mode::from_raw_mode`]: crate::fs::Mode::from_raw_mode
+/// [`FileType::from_raw_mode`]: crate::fs::FileType::from_raw_mode
 #[inline]
 pub fn fstat<Fd: AsFd>(fd: &Fd) -> io::Result<Stat> {
     let fd = fd.as_fd();
-    imp::syscalls::fstat(fd)
+    imp::fs::syscalls::fstat(fd)
 }
 
 /// `fstatfs(fd)`—Queries filesystem statistics for an open file or directory.
@@ -105,11 +116,16 @@ pub fn fstat<Fd: AsFd>(fd: &Fd) -> io::Result<Stat> {
 ///  - [Linux]
 ///
 /// [Linux]: https://man7.org/linux/man-pages/man2/fstatfs.2.html
-#[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "wasi")))] // not implemented in libc for netbsd yet
+#[cfg(not(any(
+    target_os = "illumos",
+    target_os = "netbsd",
+    target_os = "redox",
+    target_os = "wasi"
+)))] // not implemented in libc for netbsd yet
 #[inline]
 pub fn fstatfs<Fd: AsFd>(fd: &Fd) -> io::Result<StatFs> {
     let fd = fd.as_fd();
-    imp::syscalls::fstatfs(fd)
+    imp::fs::syscalls::fstatfs(fd)
 }
 
 /// `futimens(fd, times)`—Sets timestamps for an open file or directory.
@@ -121,9 +137,9 @@ pub fn fstatfs<Fd: AsFd>(fd: &Fd) -> io::Result<StatFs> {
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/futimens.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/utimensat.2.html
 #[inline]
-pub fn futimens<Fd: AsFd>(fd: &Fd, times: &[Timespec; 2]) -> io::Result<()> {
+pub fn futimens<Fd: AsFd>(fd: &Fd, times: &Timestamps) -> io::Result<()> {
     let fd = fd.as_fd();
-    imp::syscalls::futimens(fd, times)
+    imp::fs::syscalls::futimens(fd, times)
 }
 
 /// `fallocate(fd, mode, offset, len)`—Adjusts file allocation.
@@ -143,6 +159,7 @@ pub fn futimens<Fd: AsFd>(fd: &Fd, times: &[Timespec; 2]) -> io::Result<()> {
 /// [Linux `posix_fallocate`]: https://man7.org/linux/man-pages/man3/posix_fallocate.3.html
 #[cfg(not(any(
     target_os = "dragonfly",
+    target_os = "illumos",
     target_os = "netbsd",
     target_os = "openbsd",
     target_os = "redox"
@@ -151,7 +168,7 @@ pub fn futimens<Fd: AsFd>(fd: &Fd, times: &[Timespec; 2]) -> io::Result<()> {
 #[doc(alias = "posix_fallocate")]
 pub fn fallocate<Fd: AsFd>(fd: &Fd, mode: FallocateFlags, offset: u64, len: u64) -> io::Result<()> {
     let fd = fd.as_fd();
-    imp::syscalls::fallocate(fd, mode, offset, len)
+    imp::fs::syscalls::fallocate(fd, mode, offset, len)
 }
 
 /// `fcntl(fd, F_GETFL) & O_ACCMODE`
@@ -167,7 +184,7 @@ pub fn is_file_read_write<Fd: AsFd>(fd: &Fd) -> io::Result<(bool, bool)> {
 }
 
 pub(crate) fn _is_file_read_write(fd: BorrowedFd<'_>) -> io::Result<(bool, bool)> {
-    let mode = imp::syscalls::fcntl_getfl(fd)?;
+    let mode = imp::fs::syscalls::fcntl_getfl(fd)?;
 
     // Check for `O_PATH`.
     #[cfg(any(
@@ -193,16 +210,20 @@ pub(crate) fn _is_file_read_write(fd: BorrowedFd<'_>) -> io::Result<(bool, bool)
 /// `fsync(fd)`—Ensures that file data and metadata is written to the
 /// underlying storage device.
 ///
+/// Note that on iOS and macOS this isn't sufficient to ensure that data has
+/// reached persistent storage; use [`fcntl_fullfsync`] to ensure that.
+///
 /// # References
 ///  - [POSIX]
 ///  - [Linux]
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/fsync.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/fsync.2.html
+/// [`fcntl_fullfsync`]: https://docs.rs/rustix/*/x86_64-apple-darwin/rustix/fs/fn.fcntl_fullfsync.html
 #[inline]
 pub fn fsync<Fd: AsFd>(fd: &Fd) -> io::Result<()> {
     let fd = fd.as_fd();
-    imp::syscalls::fsync(fd)
+    imp::fs::syscalls::fsync(fd)
 }
 
 /// `fdatasync(fd)`—Ensures that file data is written to the underlying
@@ -223,7 +244,7 @@ pub fn fsync<Fd: AsFd>(fd: &Fd) -> io::Result<()> {
 #[inline]
 pub fn fdatasync<Fd: AsFd>(fd: &Fd) -> io::Result<()> {
     let fd = fd.as_fd();
-    imp::syscalls::fdatasync(fd)
+    imp::fs::syscalls::fdatasync(fd)
 }
 
 /// `ftruncate(fd, length)`—Sets the length of a file.
@@ -237,7 +258,7 @@ pub fn fdatasync<Fd: AsFd>(fd: &Fd) -> io::Result<()> {
 #[inline]
 pub fn ftruncate<Fd: AsFd>(fd: &Fd, length: u64) -> io::Result<()> {
     let fd = fd.as_fd();
-    imp::syscalls::ftruncate(fd, length)
+    imp::fs::syscalls::ftruncate(fd, length)
 }
 
 /// `flock(fd, operation)`—Acquire or release an advisory lock on an open file.
@@ -250,5 +271,5 @@ pub fn ftruncate<Fd: AsFd>(fd: &Fd, length: u64) -> io::Result<()> {
 #[inline]
 pub fn flock<Fd: AsFd>(fd: &Fd, operation: FlockOperation) -> io::Result<()> {
     let fd = fd.as_fd();
-    imp::syscalls::flock(fd, operation)
+    imp::fs::syscalls::flock(fd, operation)
 }
