@@ -15,7 +15,7 @@ use super::super::c;
 #[cfg(all(target_pointer_width = "32", target_arch = "arm"))]
 use super::super::conv::zero;
 use super::super::conv::{
-    borrowed_fd, by_ref, c_int, c_str, c_uint, dev_t, mode_and_type_as, mode_as, oflags,
+    borrowed_fd, by_ref, c_int, c_str, c_uint, dev_t, fs_advice, mode_and_type_as, mode_as, oflags,
     oflags_for_open_how, opt_c_str, opt_mut, out, pass_usize, raw_fd, ret, ret_c_int, ret_c_uint,
     ret_owned_fd, ret_usize, size_of, slice_mut,
 };
@@ -28,7 +28,7 @@ use super::{
 use crate::fd::AsFd;
 use crate::fd::{BorrowedFd, RawFd};
 use crate::ffi::ZStr;
-use crate::fs::{FileType, Timestamps};
+use crate::fs::{FileType, SealFlags, Timestamps};
 use crate::io::{self, OwnedFd, SeekFrom};
 use crate::process::{Gid, Uid};
 use core::convert::TryInto;
@@ -42,26 +42,23 @@ use linux_raw_sys::general::__NR_open;
 #[cfg(not(any(target_arch = "riscv64")))]
 use linux_raw_sys::general::__NR_renameat;
 use linux_raw_sys::general::{
-    __NR_faccessat, __NR_fallocate, __NR_fchmod, __NR_fchmodat, __NR_fchown, __NR_fchownat,
-    __NR_fdatasync, __NR_flock, __NR_fsync, __NR_getdents64, __NR_linkat, __NR_mkdirat,
-    __NR_mknodat, __NR_openat, __NR_readlinkat, __NR_symlinkat, __NR_unlinkat, __NR_utimensat,
-    __kernel_timespec, AT_FDCWD, AT_REMOVEDIR, AT_SYMLINK_NOFOLLOW, F_DUPFD, F_DUPFD_CLOEXEC,
-    F_GETFD, F_GETFL, F_GETLEASE, F_GETOWN, F_GETSIG, F_SETFD, F_SETFL,
-};
-use linux_raw_sys::v5_11::general::{__NR_openat2, open_how};
-use linux_raw_sys::v5_4::general::{
-    __NR_copy_file_range, __NR_memfd_create, __NR_renameat2, __NR_statx, statx, F_GETPIPE_SZ,
-    F_GET_SEALS, F_SETPIPE_SZ,
+    __NR_copy_file_range, __NR_faccessat, __NR_fallocate, __NR_fchmod, __NR_fchmodat, __NR_fchown,
+    __NR_fchownat, __NR_fdatasync, __NR_flock, __NR_fsync, __NR_getdents64, __NR_linkat,
+    __NR_memfd_create, __NR_mkdirat, __NR_mknodat, __NR_openat, __NR_openat2, __NR_readlinkat,
+    __NR_renameat2, __NR_statx, __NR_symlinkat, __NR_unlinkat, __NR_utimensat, __kernel_timespec,
+    open_how, statx, AT_FDCWD, AT_REMOVEDIR, AT_SYMLINK_NOFOLLOW, F_ADD_SEALS, F_DUPFD,
+    F_DUPFD_CLOEXEC, F_GETFD, F_GETFL, F_GETLEASE, F_GETOWN, F_GETPIPE_SZ, F_GETSIG, F_GET_SEALS,
+    F_SETFD, F_SETFL, F_SETPIPE_SZ,
 };
 #[cfg(target_pointer_width = "32")]
 use {
     super::super::arch::choose::syscall6_readonly,
     super::super::conv::{hi, lo, slice_just_addr},
+    linux_raw_sys::general::__NR_utimensat_time64,
     linux_raw_sys::general::{
         __NR__llseek, __NR_fcntl64, __NR_fstat64, __NR_fstatat64, __NR_fstatfs64, __NR_ftruncate64,
         __NR_sendfile64, __NR_statfs64, timespec as __kernel_old_timespec,
     },
-    linux_raw_sys::v5_4::general::__NR_utimensat_time64,
 };
 #[cfg(target_pointer_width = "64")]
 use {
@@ -387,7 +384,7 @@ pub(crate) fn fadvise(fd: BorrowedFd<'_>, pos: u64, len: u64, advice: Advice) ->
         ret(syscall6_readonly(
             nr(__NR_fadvise64_64),
             borrowed_fd(fd),
-            c_uint(advice as c::c_uint),
+            fs_advice(advice),
             hi(pos),
             lo(pos),
             hi(len),
@@ -406,7 +403,7 @@ pub(crate) fn fadvise(fd: BorrowedFd<'_>, pos: u64, len: u64, advice: Advice) ->
             lo(pos),
             hi(len),
             lo(len),
-            c_uint(advice as c::c_uint),
+            fs_advice(advice),
         ))
     }
     #[cfg(target_pointer_width = "64")]
@@ -416,7 +413,7 @@ pub(crate) fn fadvise(fd: BorrowedFd<'_>, pos: u64, len: u64, advice: Advice) ->
             borrowed_fd(fd),
             loff_t_from_u64(pos),
             loff_t_from_u64(len),
-            c_uint(advice as c::c_uint),
+            fs_advice(advice),
         ))
     }
 }
@@ -876,7 +873,7 @@ pub(crate) fn fcntl_setpipe_sz(fd: BorrowedFd<'_>, size: c::c_int) -> io::Result
 }
 
 #[inline]
-pub(crate) fn fcntl_get_seals(fd: BorrowedFd<'_>) -> io::Result<u32> {
+pub(crate) fn fcntl_get_seals(fd: BorrowedFd<'_>) -> io::Result<SealFlags> {
     #[cfg(target_pointer_width = "32")]
     unsafe {
         ret_c_int(syscall2_readonly(
@@ -884,7 +881,7 @@ pub(crate) fn fcntl_get_seals(fd: BorrowedFd<'_>) -> io::Result<u32> {
             borrowed_fd(fd),
             c_uint(F_GET_SEALS),
         ))
-        .map(|seals| seals as u32)
+        .map(|seals| SealFlags::from_bits_unchecked(seals as u32))
     }
     #[cfg(target_pointer_width = "64")]
     unsafe {
@@ -893,7 +890,29 @@ pub(crate) fn fcntl_get_seals(fd: BorrowedFd<'_>) -> io::Result<u32> {
             borrowed_fd(fd),
             c_uint(F_GET_SEALS),
         ))
-        .map(|seals| seals as u32)
+        .map(|seals| SealFlags::from_bits_unchecked(seals as u32))
+    }
+}
+
+#[inline]
+pub(crate) fn fcntl_add_seals(fd: BorrowedFd<'_>, seals: SealFlags) -> io::Result<()> {
+    #[cfg(target_pointer_width = "32")]
+    unsafe {
+        ret(syscall3_readonly(
+            nr(__NR_fcntl64),
+            borrowed_fd(fd),
+            c_uint(F_ADD_SEALS),
+            c_uint(seals.bits()),
+        ))
+    }
+    #[cfg(target_pointer_width = "64")]
+    unsafe {
+        ret(syscall3_readonly(
+            nr(__NR_fcntl),
+            borrowed_fd(fd),
+            c_uint(F_ADD_SEALS),
+            c_uint(seals.bits()),
+        ))
     }
 }
 
@@ -1126,56 +1145,16 @@ fn _utimensat(
 
     #[cfg(target_pointer_width = "32")]
     unsafe {
-        ret(syscall4_readonly(
+        match ret(syscall4_readonly(
             nr(__NR_utimensat_time64),
             borrowed_fd(dirfd),
             opt_c_str(pathname),
             by_ref(times),
             c_uint(flags.bits()),
-        ))
-        .or_else(|err| {
-            // See the comments in `rustix_clock_gettime_via_syscall` about
-            // emulation.
-            if err == io::Error::NOSYS {
-                let old_times = [
-                    __kernel_old_timespec {
-                        tv_sec: times
-                            .last_access
-                            .tv_sec
-                            .try_into()
-                            .map_err(|_| io::Error::INVAL)?,
-                        tv_nsec: times
-                            .last_access
-                            .tv_nsec
-                            .try_into()
-                            .map_err(|_| io::Error::INVAL)?,
-                    },
-                    __kernel_old_timespec {
-                        tv_sec: times
-                            .last_modification
-                            .tv_sec
-                            .try_into()
-                            .map_err(|_| io::Error::INVAL)?,
-                        tv_nsec: times
-                            .last_modification
-                            .tv_nsec
-                            .try_into()
-                            .map_err(|_| io::Error::INVAL)?,
-                    },
-                ];
-                // The length of the array is fixed and not passed into the syscall.
-                let old_times_addr = slice_just_addr(&old_times);
-                ret(syscall4_readonly(
-                    nr(__NR_utimensat),
-                    borrowed_fd(dirfd),
-                    opt_c_str(pathname),
-                    old_times_addr,
-                    c_uint(flags.bits()),
-                ))
-            } else {
-                Err(err)
-            }
-        })
+        )) {
+            Err(io::Error::NOSYS) => _utimensat_old(dirfd, pathname, times, flags),
+            otherwise => otherwise,
+        }
     }
     #[cfg(target_pointer_width = "64")]
     unsafe {
@@ -1189,6 +1168,52 @@ fn _utimensat(
     }
 }
 
+#[cfg(target_pointer_width = "32")]
+unsafe fn _utimensat_old(
+    dirfd: BorrowedFd<'_>,
+    pathname: Option<&ZStr>,
+    times: &Timestamps,
+    flags: AtFlags,
+) -> io::Result<()> {
+    // See the comments in `rustix_clock_gettime_via_syscall` about
+    // emulation.
+    let old_times = [
+        __kernel_old_timespec {
+            tv_sec: times
+                .last_access
+                .tv_sec
+                .try_into()
+                .map_err(|_| io::Error::INVAL)?,
+            tv_nsec: times
+                .last_access
+                .tv_nsec
+                .try_into()
+                .map_err(|_| io::Error::INVAL)?,
+        },
+        __kernel_old_timespec {
+            tv_sec: times
+                .last_modification
+                .tv_sec
+                .try_into()
+                .map_err(|_| io::Error::INVAL)?,
+            tv_nsec: times
+                .last_modification
+                .tv_nsec
+                .try_into()
+                .map_err(|_| io::Error::INVAL)?,
+        },
+    ];
+    // The length of the array is fixed and not passed into the syscall.
+    let old_times_addr = slice_just_addr(&old_times);
+    ret(syscall4_readonly(
+        nr(__NR_utimensat),
+        borrowed_fd(dirfd),
+        opt_c_str(pathname),
+        old_times_addr,
+        c_uint(flags.bits()),
+    ))
+}
+
 #[inline]
 pub(crate) fn futimens(fd: BorrowedFd<'_>, times: &Timestamps) -> io::Result<()> {
     _utimensat(fd, None, times, AtFlags::empty())
@@ -1201,14 +1226,14 @@ pub(crate) fn accessat(
     flags: AtFlags,
 ) -> io::Result<()> {
     if flags.is_empty()
-        || (flags.bits() == linux_raw_sys::v5_11::general::AT_EACCESS
+        || (flags.bits() == linux_raw_sys::general::AT_EACCESS
             && crate::process::getuid() == crate::process::geteuid()
             && crate::process::getgid() == crate::process::getegid())
     {
         return _accessat(dirfd, path, access.bits());
     }
 
-    if flags.bits() != linux_raw_sys::v5_11::general::AT_EACCESS {
+    if flags.bits() != linux_raw_sys::general::AT_EACCESS {
         return Err(io::Error::INVAL);
     }
 
