@@ -14,8 +14,8 @@ use super::super::conv::{
 };
 use super::super::reg::nr;
 use super::{
-    encode_sockaddr_unix, encode_sockaddr_v4, encode_sockaddr_v6, read_sockaddr_os, AcceptFlags,
-    AddressFamily, Protocol, RecvFlags, SendFlags, Shutdown, SocketFlags, SocketType,
+    encode_sockaddr_v4, encode_sockaddr_v6, read_sockaddr_os, AcceptFlags, AddressFamily, Protocol,
+    RecvFlags, SendFlags, Shutdown, SocketFlags, SocketType,
 };
 use crate::fd::BorrowedFd;
 use crate::io::{self, OwnedFd};
@@ -29,7 +29,7 @@ use core::mem::MaybeUninit;
     target_arch = "riscv64"
 )))]
 use linux_raw_sys::general::{__NR_recv, __NR_send};
-use linux_raw_sys::general::{sockaddr, sockaddr_in, sockaddr_in6, sockaddr_un, socklen_t};
+use linux_raw_sys::general::{sockaddr, sockaddr_in, sockaddr_in6, socklen_t};
 #[cfg(target_arch = "x86")]
 use {
     super::super::arch::choose::syscall2,
@@ -450,8 +450,8 @@ pub(crate) fn sendto_unix(
             buf_addr,
             buf_len,
             c_uint(flags.bits()),
-            by_ref(&encode_sockaddr_unix(addr)),
-            size_of::<sockaddr_un, _>(),
+            by_ref(&addr.unix),
+            socklen_t(addr.addr_len()),
         ))
     }
     #[cfg(target_arch = "x86")]
@@ -464,8 +464,8 @@ pub(crate) fn sendto_unix(
                 buf_addr,
                 buf_len,
                 c_uint(flags.bits()),
-                by_ref(&encode_sockaddr_unix(addr)),
-                size_of::<sockaddr_un, _>(),
+                by_ref(&addr.unix),
+                socklen_t(addr.addr_len()),
             ]),
         ))
     }
@@ -701,8 +701,8 @@ pub(crate) fn bind_unix(fd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io::Result
         ret(syscall3_readonly(
             nr(__NR_bind),
             borrowed_fd(fd),
-            by_ref(&encode_sockaddr_unix(addr)),
-            size_of::<sockaddr_un, _>(),
+            by_ref(&addr.unix),
+            socklen_t(addr.addr_len()),
         ))
     }
     #[cfg(target_arch = "x86")]
@@ -712,8 +712,8 @@ pub(crate) fn bind_unix(fd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io::Result
             x86_sys(SYS_BIND),
             slice_just_addr::<ArgReg<SocketArg>, _>(&[
                 borrowed_fd(fd),
-                by_ref(&encode_sockaddr_unix(addr)),
-                size_of::<sockaddr_un, _>(),
+                by_ref(&addr.unix),
+                socklen_t(addr.addr_len()),
             ]),
         ))
     }
@@ -776,8 +776,8 @@ pub(crate) fn connect_unix(fd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io::Res
         ret(syscall3_readonly(
             nr(__NR_connect),
             borrowed_fd(fd),
-            by_ref(&encode_sockaddr_unix(addr)),
-            size_of::<sockaddr_un, _>(),
+            by_ref(&addr.unix),
+            socklen_t(addr.addr_len()),
         ))
     }
     #[cfg(target_arch = "x86")]
@@ -787,8 +787,8 @@ pub(crate) fn connect_unix(fd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io::Res
             x86_sys(SYS_CONNECT),
             slice_just_addr::<ArgReg<SocketArg>, _>(&[
                 borrowed_fd(fd),
-                by_ref(&encode_sockaddr_unix(addr)),
-                size_of::<sockaddr_un, _>(),
+                by_ref(&addr.unix),
+                socklen_t(addr.addr_len()),
             ]),
         ))
     }
@@ -821,6 +821,10 @@ pub(crate) mod sockopt {
     use crate::net::{Ipv4Addr, Ipv6Addr, SocketType};
     use core::convert::TryInto;
     use core::time::Duration;
+    use linux_raw_sys::general::{
+        __kernel_timespec, timeval, SOL_SOCKET, SO_RCVTIMEO_NEW, SO_RCVTIMEO_OLD, SO_SNDTIMEO_NEW,
+        SO_SNDTIMEO_OLD,
+    };
 
     // TODO: With Rust 1.53 we can use `Duration::ZERO` instead.
     const DURATION_ZERO: Duration = Duration::from_secs(0);
@@ -998,31 +1002,32 @@ pub(crate) mod sockopt {
         id: Timeout,
         timeout: Option<Duration>,
     ) -> io::Result<()> {
-        let timeout = match timeout {
-            Some(timeout) => {
-                if timeout == DURATION_ZERO {
-                    return Err(io::Error::INVAL);
-                }
-
-                let mut timeout = linux_raw_sys::general::timeval {
-                    tv_sec: timeout.as_secs().try_into().unwrap_or(c::c_long::MAX),
-                    tv_usec: timeout.subsec_micros() as _,
-                };
-                if timeout.tv_sec == 0 && timeout.tv_usec == 0 {
-                    timeout.tv_usec = 1;
-                }
-                timeout
-            }
-            None => linux_raw_sys::general::timeval {
-                tv_sec: 0,
-                tv_usec: 0,
-            },
-        };
+        let time = duration_to_linux(timeout)?;
         let optname = match id {
-            Timeout::Recv => linux_raw_sys::general::SO_RCVTIMEO,
-            Timeout::Send => linux_raw_sys::general::SO_SNDTIMEO,
+            Timeout::Recv => SO_RCVTIMEO_NEW,
+            Timeout::Send => SO_SNDTIMEO_NEW,
         };
-        setsockopt(fd, linux_raw_sys::general::SOL_SOCKET, optname, timeout)
+        match setsockopt(fd, SOL_SOCKET, optname, time) {
+            Err(io::Error::NOPROTOOPT) if SO_RCVTIMEO_NEW != SO_RCVTIMEO_OLD => {
+                set_socket_timeout_old(fd, id, timeout)
+            }
+            otherwise => otherwise,
+        }
+    }
+
+    /// Same as `set_socket_timeout` but uses `timeval` instead of
+    /// `__kernel_timespec` and `_OLD` constants instead of `_NEW`.
+    fn set_socket_timeout_old(
+        fd: BorrowedFd<'_>,
+        id: Timeout,
+        timeout: Option<Duration>,
+    ) -> io::Result<()> {
+        let time = duration_to_linux_old(timeout)?;
+        let optname = match id {
+            Timeout::Recv => SO_RCVTIMEO_OLD,
+            Timeout::Send => SO_SNDTIMEO_OLD,
+        };
+        setsockopt(fd, SOL_SOCKET, optname, time)
     }
 
     #[inline]
@@ -1031,21 +1036,100 @@ pub(crate) mod sockopt {
         id: Timeout,
     ) -> io::Result<Option<Duration>> {
         let optname = match id {
-            Timeout::Recv => linux_raw_sys::general::SO_RCVTIMEO,
-            Timeout::Send => linux_raw_sys::general::SO_SNDTIMEO,
+            Timeout::Recv => SO_RCVTIMEO_NEW,
+            Timeout::Send => SO_SNDTIMEO_NEW,
         };
-        let timeout: linux_raw_sys::general::timeval =
-            getsockopt(fd, linux_raw_sys::general::SOL_SOCKET, optname)?;
-        if timeout.tv_sec == 0 && timeout.tv_usec == 0 {
-            Ok(None)
+        let time: __kernel_timespec = match getsockopt(fd, SOL_SOCKET, optname) {
+            Err(io::Error::NOPROTOOPT) if SO_RCVTIMEO_NEW != SO_RCVTIMEO_OLD => {
+                return get_socket_timeout_old(fd, id)
+            }
+            otherwise => otherwise?,
+        };
+        Ok(duration_from_linux(time))
+    }
+
+    /// Same as `get_socket_timeout` but uses `timeval` instead of
+    /// `__kernel_timespec` and `_OLD` constants instead of `_NEW`.
+    fn get_socket_timeout_old(fd: BorrowedFd<'_>, id: Timeout) -> io::Result<Option<Duration>> {
+        let optname = match id {
+            Timeout::Recv => SO_RCVTIMEO_OLD,
+            Timeout::Send => SO_SNDTIMEO_OLD,
+        };
+        let time: timeval = getsockopt(fd, SOL_SOCKET, optname)?;
+        Ok(duration_from_linux_old(time))
+    }
+
+    /// Convert a C `timespec` to a Rust `Option<Duration>`.
+    #[inline]
+    fn duration_from_linux(time: __kernel_timespec) -> Option<Duration> {
+        if time.tv_sec == 0 && time.tv_nsec == 0 {
+            None
         } else {
-            Ok(Some(
-                Duration::from_secs(timeout.tv_sec as u64)
-                    + Duration::from_micros(timeout.tv_usec as u64),
-            ))
+            Some(
+                Duration::from_secs(time.tv_sec as u64) + Duration::from_nanos(time.tv_nsec as u64),
+            )
         }
     }
 
+    /// Like `duration_from_linux` but uses Linux's old 32-bit `timeval`.
+    fn duration_from_linux_old(time: timeval) -> Option<Duration> {
+        if time.tv_sec == 0 && time.tv_usec == 0 {
+            None
+        } else {
+            Some(
+                Duration::from_secs(time.tv_sec as u64)
+                    + Duration::from_micros(time.tv_usec as u64),
+            )
+        }
+    }
+
+    /// Convert a Rust `Option<Duration>` to a C `timespec`.
+    #[inline]
+    fn duration_to_linux(timeout: Option<Duration>) -> io::Result<__kernel_timespec> {
+        Ok(match timeout {
+            Some(timeout) => {
+                if timeout == DURATION_ZERO {
+                    return Err(io::Error::INVAL);
+                }
+                let mut timeout = __kernel_timespec {
+                    tv_sec: timeout.as_secs().try_into().unwrap_or(i64::MAX),
+                    tv_nsec: timeout.subsec_nanos() as _,
+                };
+                if timeout.tv_sec == 0 && timeout.tv_nsec == 0 {
+                    timeout.tv_nsec = 1;
+                }
+                timeout
+            }
+            None => __kernel_timespec {
+                tv_sec: 0,
+                tv_nsec: 0,
+            },
+        })
+    }
+
+    /// Like `duration_to_linux` but uses Linux's old 32-bit `timeval`.
+    fn duration_to_linux_old(timeout: Option<Duration>) -> io::Result<timeval> {
+        Ok(match timeout {
+            Some(timeout) => {
+                if timeout == DURATION_ZERO {
+                    return Err(io::Error::INVAL);
+                }
+                let mut timeout = timeval {
+                    tv_sec: timeout.as_secs().try_into().unwrap_or(c::c_long::MAX),
+                    tv_usec: timeout.subsec_micros() as _,
+                };
+                if timeout.tv_sec == 0 && timeout.tv_usec == 0 {
+                    timeout.tv_usec = 1;
+                }
+                timeout
+            }
+            None => timeval {
+                tv_sec: 0,
+                tv_usec: 0,
+            },
+        })
+    }
+
     #[inline]
     pub(crate) fn set_ip_ttl(fd: BorrowedFd<'_>, ttl: u32) -> io::Result<()> {
         setsockopt(
