@@ -1,4 +1,4 @@
-//! Functions which operate on file descriptors.
+//! The [`is_read_write`] function.
 
 use crate::{imp, io};
 use imp::fd::AsFd;
@@ -13,5 +13,5 @@ use imp::fd::AsFd;
 #[inline]
 pub fn is_read_write<Fd: AsFd>(fd: &Fd) -> io::Result<(bool, bool)> {
     let fd = fd.as_fd();
-    imp::syscalls::is_read_write(fd)
+    imp::io::syscalls::is_read_write(fd)
 }
