@@ -83,23 +83,30 @@
 #![allow(stable_features)]
 #![cfg_attr(linux_raw, deny(unsafe_code))]
 #![cfg_attr(asm, feature(asm))]
-#![cfg_attr(any(rustc_attrs, not(feature = "std")), feature(rustc_attrs))]
+#![cfg_attr(rustc_attrs, feature(rustc_attrs))]
 #![cfg_attr(doc_cfg, feature(doc_cfg))]
 #![cfg_attr(all(target_os = "wasi", feature = "std"), feature(wasi_ext))]
 #![cfg_attr(all(linux_raw, asm, target_arch = "x86"), feature(naked_functions))]
 #![cfg_attr(io_lifetimes_use_std, feature(io_safety))]
 #![cfg_attr(not(feature = "std"), no_std)]
-#![cfg_attr(not(feature = "std"), allow(incomplete_features))]
-#![cfg_attr(not(feature = "std"), feature(specialization))]
-#![cfg_attr(not(feature = "std"), feature(slice_internals))]
-#![cfg_attr(not(feature = "std"), feature(toowned_clone_into))]
-#![cfg_attr(not(feature = "std"), feature(vec_into_raw_parts))]
+#![cfg_attr(all(not(feature = "std"), specialization), allow(incomplete_features))]
+#![cfg_attr(all(not(feature = "std"), specialization), feature(specialization))]
+#![cfg_attr(all(not(feature = "std"), slice_internals), feature(slice_internals))]
+#![cfg_attr(
+    all(not(feature = "std"), toowned_clone_into),
+    feature(toowned_clone_into)
+)]
+#![cfg_attr(
+    all(not(feature = "std"), vec_into_raw_parts),
+    feature(vec_into_raw_parts)
+)]
 #![cfg_attr(feature = "rustc-dep-of-std", feature(core_intrinsics))]
 #![cfg_attr(feature = "rustc-dep-of-std", feature(ip))]
 #![cfg_attr(
     all(not(feature = "rustc-dep-of-std"), core_intrinsics),
     feature(core_intrinsics)
 )]
+#![cfg_attr(asm_experimental_arch, feature(asm_experimental_arch))]
 
 #[cfg(not(feature = "rustc-dep-of-std"))]
 extern crate alloc;
