@@ -2,10 +2,9 @@
 //!
 //! # Safety
 //!
-//! The `Uid`, `Gid`, and `Uid` types can be constructed from raw integers,
-//! which is marked safe for similar reasons as [`FromRawFd::from_raw_fd`].
-//!
-//! [`FromRawFd::from_raw_fd`]: https://doc.rust-lang.org/std/os/unix/io/trait.FromRawFd.html#tymethod.from_raw_fd
+//! The `Uid`, `Gid`, and `Pid` types can be constructed from raw integers,
+//! which is marked unsafe because actual OS's assign special meaning to some
+//! integer values.
 #![allow(unsafe_code)]
 
 use crate::imp;
@@ -115,6 +114,19 @@ impl Pid {
         Self(raw)
     }
 
+    /// Creates a `Pid` holding the ID of the given child process.
+    #[cfg(feature = "std")]
+    #[inline]
+    pub fn from_child(child: &std::process::Child) -> Self {
+        // Safety
+        //
+        // We know the returned ID is valid because it came directly from
+        // an OS API.
+        let id = child.id();
+        debug_assert_ne!(id, 0);
+        unsafe { Self::from_raw_nonzero(RawNonZeroPid::new_unchecked(id as _)) }
+    }
+
     /// Converts a `Pid` into a `RawNonZeroPid`.
     #[inline]
     pub const fn as_raw_nonzero(self) -> RawNonZeroPid {
@@ -158,7 +170,7 @@ impl Cpuid {
 #[inline]
 #[must_use]
 pub fn getuid() -> Uid {
-    imp::syscalls::getuid()
+    imp::process::syscalls::getuid()
 }
 
 /// `geteuid()`—Returns the process' effective user ID.
@@ -172,7 +184,7 @@ pub fn getuid() -> Uid {
 #[inline]
 #[must_use]
 pub fn geteuid() -> Uid {
-    imp::syscalls::geteuid()
+    imp::process::syscalls::geteuid()
 }
 
 /// `getgid()`—Returns the process' real group ID.
@@ -186,7 +198,7 @@ pub fn geteuid() -> Uid {
 #[inline]
 #[must_use]
 pub fn getgid() -> Gid {
-    imp::syscalls::getgid()
+    imp::process::syscalls::getgid()
 }
 
 /// `getegid()`—Returns the process' effective group ID.
@@ -200,7 +212,7 @@ pub fn getgid() -> Gid {
 #[inline]
 #[must_use]
 pub fn getegid() -> Gid {
-    imp::syscalls::getegid()
+    imp::process::syscalls::getegid()
 }
 
 /// `getpid()`—Returns the process' ID.
@@ -214,7 +226,7 @@ pub fn getegid() -> Gid {
 #[inline]
 #[must_use]
 pub fn getpid() -> Pid {
-    imp::syscalls::getpid()
+    imp::process::syscalls::getpid()
 }
 
 /// `getppid()`—Returns the parent process' ID.
@@ -228,5 +240,5 @@ pub fn getpid() -> Pid {
 #[inline]
 #[must_use]
 pub fn getppid() -> Option<Pid> {
-    imp::syscalls::getppid()
+    imp::process::syscalls::getppid()
 }
