@@ -18,11 +18,14 @@ mod from_into;
 mod isatty;
 #[cfg(not(windows))]
 mod mmap;
-#[cfg(not(windows))]
 mod poll;
+#[cfg(all(feature = "procfs", any(target_os = "android", target_os = "linux")))]
+mod procfs;
 #[cfg(not(windows))]
 mod prot;
 #[cfg(not(windows))]
 #[cfg(not(target_os = "redox"))] // redox doesn't have cwd/openat
 #[cfg(not(target_os = "wasi"))] // wasi support for S_IRUSR etc. submitted to libc in #2264
 mod read_write;
+#[cfg(any(target_os = "linux", target_os = "android"))]
+mod seals;
